import fetch from 'node-fetch'; //eslint-disable-next-line @typescript-eslint/ban-ts-comment
// @ts-ignore

import { REPLICATION_STATE } from '@resolve-js/module-replication';

const getReplicationState = async ({
  targetApplicationUrl
}) => {
  if (targetApplicationUrl == null || targetApplicationUrl.constructor !== String || targetApplicationUrl.length === 0) {
    return {
      status: 'error',
      statusData: {
        name: 'Error',
        message: 'Invalid target application url: empty or not a string. The replication is no-op'
      },
      paused: false,
      iterator: null,
      successEvent: null
    };
  }

  try {
    const response = await fetch(`${targetApplicationUrl}${REPLICATION_STATE.endpoint}`);
    const state = await response.json();

    if (response.status >= 400) {
      var _message;

      return {
        status: 'serviceError',
        statusData: {
          name: response.statusText,
          message: (_message = state.message) !== null && _message !== void 0 ? _message : response.statusText
        },
        paused: false,
        iterator: null,
        successEvent: null
      };
    }

    return state;
  } catch (error) {
    if (error.name === 'AbortError' || error.name === 'FetchError' || error.name === 'TypeError') {
      const state = {
        status: 'serviceError',
        statusData: {
          name: error.name,
          message: error.message,
          stack: error.stack ? error.stack : null
        },
        paused: false,
        iterator: null,
        successEvent: null
      };
      return state;
    } else {
      throw error;
    }
  }
};

export default getReplicationState;
//# sourceMappingURL=get-replication-state.js.map