import { ReadModelRunStatus } from '@resolve-js/readmodel-base';

const status = async (pool, readModelName) => {
  var _ref;

  const state = await pool.getReplicationState(pool);
  let runStatus = ReadModelRunStatus.DELIVER;

  if (state.status === 'error') {
    runStatus = ReadModelRunStatus.ERROR;
  } else if (state.paused) {
    runStatus = ReadModelRunStatus.SKIP;
  }

  let error = null;

  if (state.status === 'error' || state.status === 'serviceError') {
    if (state.statusData == null) {
      error = {
        message: 'Unknown error',
        name: 'Error'
      };
    } else {
      error = {
        name: state.statusData.name === undefined ? 'Error' : state.statusData.name,
        message: state.statusData.message,
        stack: state.statusData.stack === undefined ? state.statusData.message : state.statusData.stack
      };
    }
  }

  const result = {
    eventSubscriber: readModelName,
    deliveryStrategy: 'inline-ledger',
    successEvent: state.successEvent != null ? state.successEvent : {
      type: 'Init'
    },
    failedEvent: null,
    errors: error != null ? [error] : null,
    cursor: state.iterator ? (_ref = state.iterator.cursor) !== null && _ref !== void 0 ? _ref : null : null,
    status: runStatus
  };
  return result;
};

export default status;
//# sourceMappingURL=status.js.map